% CSTR model from
%
% M. J. Tenny and J. B. Rawlings.  Closed-loop behavior of nonlinear
% model predictive control.  Texas-Wisconsin Modeling and Control
% Consortium Report TWMCC-2002-03.

% Description:
% Continuous Stirred Tank Reactor with no energy balance.  The temperature of the reactor is controlled
%   directly.  There is a reaction series A->B->C.

function xdot=cstr3(t,x)

global u

% Input (1):
% Temperature (K)
T = u;

% States (2):
% Concentration of A (mol/m^3)
Ca = x(1,1);
% Concentration of B (mol/m^3)
Cb = x(2,1);
% Concentration of C (mol/m^3)
Cc = x(3,1);

% Parameters:
% Volumetric Flowrate (m^3/sec)
Q = 100;
% CSTR Volume (m^3)
V = 100;
% Feed Concentration of A (mol/m^3)
Caf = 1;
% E1/R
% E1 - Activation Energy for Rxn 1 (J/mol)
% R - Universal Gas Constant (8.31451 J/mol-K)
E1overR = 8750;
% Pre-exponential factor for Rxn 1 A->B (1/sec)
k10 = 7.2e10;

% E2/R
% E2 - Activation Energy for Rxn 2 (J/mol)
% R - Universal Gas Constant (8.31451 J/mol-K)
E2overR = 7750;
% Pre-exponential factor for Rxn 2 B->C (1/sec)
k20 = 5.2e10;
% Rate Constant for Rxn 1: -ra = k1*Ca
k1 = k10*exp(-E1overR/T);
% Rate Constant for Rxn 2: -rb = -k1*Cb + k2*Cb
k2 = k20*exp(-E2overR/T);

% Calculate xdot
xdot(1,1) = Q/V*(Caf - Ca) - k1*Ca;
xdot(2,1) = k1*Ca - k2*Cb - Q/V*Cb;
xdot(3,1) = k2*Cb - Q/V*Cc;

